package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````@!X```````!``````````&BQ````
M`````````$``.``)`$``&P`:``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````+R?````````O)\`````````
M`"````````$````&````T*L```````#0JR```````-"K(```````4`0`````
M``#8%```````````(````````@````8```#HJP```````.BK(```````Z*L@
M``````#@`0```````.`!````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````D)@```````"0F````````)"8````````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````-"K````````T*L@``````#0JR``
M`````#`$````````,`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50#U&T+6EF#X=Y8A+@AQ]CFTOIYSI1$```!&````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA%N@0""@````!&````
M2@```$X```!/````50```%8```!8````7````%T`````````7P```&(```!C
M````9```````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\"ZXY)\PN4_+/JA;&"S`8MO:PE#UF:OS&;%N9Q`0D75
M[,2)!9"(!W#3.?*+'`T4XI[:S>.>,V+;[0PZEPM6I)N6I]VC:W^IG)OAIP(*
M"HH05Z/@^TD```````````````````````````````````````````,`"@!8
M&@``````````````````&0$``!(`````````````````````````X`$``!(`
M````````````````````````7P(``!(`````````````````````````-`(`
M`!(`````````````````````````$0```"``````````````````````````
M9@(``!(`````````````````````````ZP(``!(`````````````````````
M````O````!(`````````````````````````>P(``!(`````````````````
M````````BP$``!(`````````````````````````TP(``!(`````````````
M````````````RP(``!(`````````````````````````F````!(`````````
M````````````````LP,``!(`````````````````````````%`$``!(`````
M````````````````````EP(``!(`````````````````````````B0(``!(`
M````````````````````````3@(``!(`````````````````````````Y`(`
M`!(`````````````````````````"`,``!(`````````````````````````
M;P$``!(`````````````````````````/0$``!(`````````````````````
M````R@```!(`````````````````````````N0$``!(`````````````````
M````````#0(``!(`````````````````````````10(``!(`````````````
M````````````'0(``!(`````````````````````````/`(``!(`````````
M````````````````I@$``!(`````````````````````````=`(``!(`````
M````````````````````VP$``!(`````````````````````````3`,``!(`
M````````````````````````10,``!(`````````````````````````2P$`
M`!(`````````````````````````^P(``!(`````````````````````````
M+0```"``````````````````````````JP(``!(`````````````````````
M````>````!(`````````````````````````^0$``!(`````````````````
M````````L@$``!(`````````````````````````IP```!(`````````````
M````````````9`$``!(`````````````````````````*@$``!(`````````
M````````````````:@```!(`````````````````````````'@$``!(`````
M````````````````````L@(``!(`````````````````````````FP$``!(`
M````````````````````````^````!(`````````````````````````;`(`
M`!(`````````````````````````U`$``!(`````````````````````````
M-@,``!(`````````````````````````#P,``!(`````````````````````
M````?0$``!(`````````````````````````AP```!(`````````````````
M````````/@,``!(`````````````````````````@@(``!(`````````````
M````````````/````"``````````````````````````W````!(`````````
M````````````````]`(``!(`````````````````````````6P$``!(`````
M````````````````````P`(``!(`````````````````````````+P(``!(`
M````````````````````````\0$``!(`````````````````````````G0(`
M`!(`````````````````````````4````"``````````````````````````
M&0,``"(`````````````````````````D`(``!(`````````````````````
M````*`,``!(`````````````````````````O`,``!(`#0"@5@```````'$`
M````````B@,``!(`#@"T5P``````````````````X0,``!(`#0`P1@``````
M`$0,````````60,``!(`#0"`'````````/<!````````D`,``!(`#0#`/@``
M``````4`````````3P0``!(`#0#0/@```````-8!````````200``!(`"@!8
M&@``````````````````?`0``!(`#0"`4@```````!0$````````;P,``!``
M&``@L"``````````````````R`,``!(`#0"P0````````"0`````````^P,`
M`!$`#P#`5P````````0`````````>P,``!``&`"HP"``````````````````
M1P0``!(`#0"`/0```````#``````````7`0``!(`#0"P1````````',!````
M````;@0``!(`#0``1````````'D`````````[@,``!``%P``L"``````````
M````````U0,``!(`#0#@0````````/$`````````7@,``!$`&`!(L"``````
M``@`````````:`,``!``%P`@L"``````````````````7P,``"$`&`!(L"``
M``````@`````````,`0``!$`%P`8L"````````@`````````W0(``!$`&`!@
ML"````````@`````````@`,``!(`#0"P5P````````(`````````(`0``!(`
M#0!`5P```````&4`````````]`,``!(`#0"`'@```````"H`````````\`,`
M`"``%P``L"``````````````````"0$``!$`&``@L"````````0`````````
M8`,``"$`&`!(L"````````@`````````H0,``!(`#0"`1````````"0`````
M````"@0``!(`#0``/@```````+D`````````ZP```!$`&`!`L"````````$`
M````````.@0``!(`#0#@00```````!("`````````&QI8G!E<FPN<V\N-2XR
M,@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)P=&AR96%D+G-O
M+C``;W!E;C8T`')E860`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F
M;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M=&]K`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`
M7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T
M9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R
M7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER
M`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C
M7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`
M>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N
M=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`1TQ)
M0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`````
M```"``,``@`"`````@`"`````@````(``@````(````"``(`!``"``(`````
M```````#``(`!0`"`````@`#``(``@````8````'`````P`"````````````
M```&```````"``,``@`"```````"``(```````(````"``(``P`&`````@`"
M``8``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``(``0`"``$`
M`@`!``$``0`!`````@`!``$````!``$``0#$`0``$````"````!U&FD)```#
M`)($`````````0`%`!,"```0`````````)21E@8```<`G@0``!````!T&6D)
M```&`*D$```0````<AEI"0``!0"U!```$````!1I:0T```0`P00``!````!U
M&FD)```"`)($````````T*L@```````(`````````(`?````````V*L@````
M```(`````````$`?````````"+`@```````(``````````BP(```````&+`@
M```````(`````````!!;````````X*T@```````&`````@``````````````
MZ*T@```````&`````P``````````````\*T@```````&````!```````````
M````^*T@```````&````!0```````````````*X@```````&````!@``````
M````````"*X@```````&````!P``````````````$*X@```````&````"```
M````````````&*X@```````&````"0``````````````(*X@```````&````
M"@``````````````**X@```````&````"P``````````````,*X@```````&
M````#```````````````.*X@```````&````#0``````````````0*X@````
M```&````#@``````````````2*X@```````&````#P``````````````4*X@
M```````&````$```````````````6*X@```````&````$0``````````````
M8*X@```````&````$@``````````````:*X@```````&````$P``````````
M````<*X@```````&````%```````````````>*X@```````&````%0``````
M````````@*X@```````&````%@``````````````B*X@```````&````%P``
M````````````D*X@```````&````&```````````````F*X@```````&````
M&0``````````````H*X@```````&````&@``````````````J*X@```````&
M````&P``````````````L*X@```````&````'```````````````N*X@````
M```&````'0``````````````P*X@```````&````'@``````````````R*X@
M```````&````'P``````````````T*X@```````&````(```````````````
MV*X@```````&````(0``````````````X*X@```````&````(@``````````
M````Z*X@```````&````(P``````````````\*X@```````&````)```````
M````````^*X@```````&````)0```````````````*\@```````&````)@``
M````````````"*\@```````&````)P``````````````$*\@```````&````
M*```````````````&*\@```````&````*0``````````````(*\@```````&
M````*@``````````````**\@```````&````*P``````````````,*\@````
M```&````+```````````````.*\@```````&````+0``````````````0*\@
M```````&````+@``````````````2*\@```````&````+P``````````````
M4*\@```````&````,```````````````6*\@```````&````,0``````````
M````8*\@```````&````,@``````````````:*\@```````&````,P``````
M````````<*\@```````&````-```````````````>*\@```````&````-0``
M````````````@*\@```````&````-@``````````````B*\@```````&````
M-P``````````````D*\@```````&````.```````````````F*\@```````&
M````.0``````````````H*\@```````&````.@``````````````J*\@````
M```&````.P``````````````L*\@```````&````/```````````````N*\@
M```````&````/0``````````````P*\@```````&````/@``````````````
MR*\@```````&````/P``````````````T*\@```````&````0```````````
M````V*\@```````&````00``````````````X*\@```````&````0@``````
M````````Z*\@```````&````0P``````````````\*\@```````&````1```
M````````````^*\@```````&````10``````````````(+`@```````%````
M8```````````````0+`@```````%````9```````````````2+`@```````%
M````5P``````````````8+`@```````%````6P``````````````2(/L"$B+
M!964(`!(A<!T!>@K`0``2(/$",,``````````````````/\U2I,@`/\E3),@
M``\?0`#_)4J3(`!FD/\E2I,@`&:0_R5*DR``9I#_)4J3(`!FD/\E4I,@`&:0
M_R52DR``9I#_)5*3(`!FD/\E4I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@
M`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E
M6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!F
MD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3
M(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_
M)5J3(`!FD/\E6I,@`&:0_R5:DR``9I#_)5J3(`!FD/\E6I,@`&:0_R5:DR``
M9I#_)5J3(`!FD/\E8I,@`&:0_R5BDR``9I#_)6*3(`!FD/\E8I,@`&:0_R5B
MDR``9I#_)6*3(`!FD/\E8I,@`&:0_R5BDR``9I#_)6*3(`!FD/\E8I,@`&:0
M_R5JDR``9I#_)6J3(`!FD/\E<I,@`&:0_R5RDR``9I#_)7*3(`!FD/\E<I,@
M`&:0_R5RDR``9I#_)7*3(`!FD/\E<I,@`&:0_R5ZDR``9I#_)7J3(`!FD/\E
M>I,@`&:055-(@^PXB7PD'$B)="002(U\)!Q(B50D"$B-="002(U4)`AD2(L$
M)2@```!(B40D*#'`Z/#^__](BS5QDB``2(L]PI(@`$B)\NA2.@``@#UKDR``
M`'4OZ%S^__](A<!(B06ZHR``#X1\`0``2(G'Z.S]__^+/2:3(`#HL?[__\:`
MQ0@```"+/123(`!(C1V,/```Z)C^__^`B,($```"BSW[DB``Z(;^__^`B,($
M```!BT0D'(UX!4AC_TC!YP/H'/[__TB+?"002(D%.*,@`+X%````QP4QHR``
M!````$B+%TB)6`A(C1TU/```2(/'"$B)6!A(B1!(BQ69DB``2(E0$(M4)!R#
M^@&-2@1^%Y!,BP],8\:#Q@%(@\<(.<Y.B4S`^'7J2(L]\Z(@`$ACR4B--?D?
M``!(QT3(^`````"#P@-%,<!(B<'H&O[__X7`B<-T44B+/<6B(`!(C6PD).@[
M_?__2(T]=SH``#'`2(GNZ`H9``!(A<!T.DB+/9ZB(`#HZ?S__^C$_?__B=A(
MBUPD*&1(,QPE*````'542(/$.%M=PTB+/72B(`#H#_[__XG#ZY](BSU<HB``
M2(7_=`?H6C@``.NS2(T]R3D``$B)[NBI&```2(7`2(G'2(D%-*(@`'25Z]F_
M`0```.C>_?__Z)'\__]F#Q^$```````Q[4F)T5Y(B>)(@^3P4%1,C04:.0``
M2(T-HS@``$B-/=S]___HS_S___1F#Q]$``!(C3UID2``2(T%:9$@`%5(*?A(
MB>5(@_@.=A5(BP4NCR``2(7`=`E=_^!F#Q]$``!=PP\?0`!F+@\?A```````
M2(T]*9$@`$B--2*1(`!52"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!<&0
M(`!(A<!T#%W_X&8/'X0``````%W##Q]``&8N#Q^$``````"`/2&1(```=2=(
M@SV7D"```%5(B>5T#$B+/:J0(`#H!?W__^A(____7<8%^)`@``'SPP\?0`!F
M+@\?A```````2(T]68P@`$B#/P!U"^E>____9@\?1```2(L%`9`@`$B%P'3I
M54B)Y?_07>E`____05=!5DB-3SA!54%43(U7>%532('LF`(``&1(BP0E*```
M`$B)A"2(`@``,<!(B>9)B>!F#Q]$``"+$4B+`4B#P0A)@\`0#\J)TTB)PDC!
MZB!)B5CP28G12,'B"$G!X1B!X@``_P!%B<E,"<I)B<%(P>@H2<'I."4`_P``
M3`G*2`G028E`^$PYT76N2(U6:$B!QF@"```/'P!(BP)(,T+82(/""$@S0J!(
M,T*02(T,`$C!Z!]("<B#X/](B4(02#GR==9,BP](BU\@3(M7$$R+7QA(BV\(
M3(G*3(G(38G,2,'B!4C!Z!M,B=E("=!(B=I(`Q0DB<!)B>U(`TPD"$G!Y1Y)
MP>0>2(V4$)EY@EI,B=!,,=A((>A,,=A(`=!(B>I(P>H"08G'20G53(G23(G^
M18GM2,'F!4PQZDPARDPQTDB-C`J9>8):3(GZ2,'J&T@)\HG22(TT$4R)RDR)
M^4C!Z@)(]]%)"=1,(>E!B?!%B>1,(>!("<%,B=!(`T0D$$B-E`&9>8):3(G!
M3(G`2,'A!4C!Z!M("<B)P$B-#`),B?I,B?A(P>@"2,'B'D@)PDR)P$&)SHG2
M2/?03"'@2"'63`-L)!A("<9,B?!,`V0D($C!Z!M)C;0UF7F"6DV)]4G!Y05,
M">B)P$R-+`9,B<!)P>@"2,'@'DD)P$R)\$6)[T6)P$CWT$@AT$PAP4@#5"0H
M2`G!3(GX28VT#)EY@EI,B?E(P>@;2,'A!4@)R(G`2(T,!DR)\$G![@)(P>`>
M3(G^20G&2/?608G,1(GP3"'&22'%20GU3(GF3HVL*IEY@EI,B>)(P>X;2,'B
M!4@)\DR)_DG![P)(P>8>B=),`>I)"?=-B>5$B?Y)]]5!B=9)(<5((?%,">E,
M`T0D,$@#1"0X38VL")EY@EI-B?!,B?%)P>`%2,'I&TP)P8G)38U$#0!,B>%)
MP>P"2,'A'DD)S$6)Q42)X4V)]$GWU$@ARDDA]$@#="1`3`GB3(VD$)EY@EI,
MB>A,B>I(P>H;2,'@!4@)T$R)\DG![@)(P>(>B<!)"=9,`>!$B?)-B>Y!B<1)
M]]9)(=!)(<Y-"?!.C;0&F7F"6DR)YDV)X$G!Z!M(P>8%3`G&38GH2<'M`DG!
MX!Z)]DT)Q4P!]D6)Z$V)Y4&)]DGWU4PAP$DAU4P)Z$@#3"1(2`-4)%!,C:P!
MF7F"6DR)\4R)\$C!X05(P>@;2`G(B<!)C4P%`$R)X$G![`)(P>`>20G$08G-
M1(G@38GT2??42"'&32'$3`-$)%A,">9,C:0RF7F"6DR)ZDR)[DC![AM(P>(%
M2`GR3(GV2<'N`DC!YAZ)TDD)]DP!XD2)]DV)[D&)U$GWUD@A\4DAQDP)\4V-
MM`B9>8):38G@3(GA2<'@!4C!Z1M,"<&)R4V-!`Y,B>E)P>T"2,'A'DD)S46)
MQD2)Z4V)Y4GWU4@ARDDA]4P)ZD@#1"1@2`-T)&A,C:P0F7F"6DR)\$R)\DC!
MZAM(P>`%2`G03(GB2<'L`DC!XAZ)P$D)U$P!Z$2)XDV)]$&)Q4GWU$DAT$DA
MS$@#3"1P30G@3HVD!IEY@EI,B>Y-B>A)P>@;2,'F!4P)QDV)\$G![@))P>`>
MB?9-"<9,`>9%B?!-B>Y!B?1)]]9,(<!)(=9,"?!,C;0!F7F"6DR)X4R)X$C!
MX05(P>@;2`G(B<!)C0P&3(GH2<'M`DC!X!Y)"<5!B<Y$B>A-B>5)]]5((<9-
M(<5,">Y(`U0D>$P#A"2`````3(VL,IEY@EI,B?),B?9(P>X;2,'B!4@)\DR)
MYDG![`)(P>8>B=))"?1,`>I$B>9-B?1!B=5)]]1((?%)(<1(`X0DB````$P)
MX4V)[$V-A`B9>8):3(GI2<'D!4C!Z1M,">&)R4V-)`A,B?%)P>X"2,'A'DD)
MSD6)X$2)\4V)[DGWUD@ARDDA]D@#M"20````3`GR38G&2(V4$)EY@EI,B<!)
MP>8%2,'H&TP)\(G`3(TT`DR)ZDG![0)(P>(>20G51(GP1(GJ38G%28G'2??5
M22'422'-30GL2<'G!4V)Q4Z-I":9>8):2(G&2<'H`DC![AM)P>4>2`.,))@`
M``!,"?Y-"<6)]D6)Z$V-/#1(B<9-(<9(]]9,`X0DJ````$@AUD6)_$@#E"2@
M````20GV3(GF3HVT,9EY@EI,B>%(P>8%2,'I&T@)\8G)28TT#DB)P4C!Z`)(
MP>$>2`G(08GV23'%13'O38GU2HV,.J'KV6Y,B?))P>4%2,'J&TP)ZHG23(TL
M$4R)X4G![`)(P>$>2(G"B<!,">%%B>]-B?1(,<I)P>0>,=9,B?I)C;0PH>O9
M;DV)^$C!ZAM)P>`%3`G"2<'N`D@#A"2P````B=)-"?1,C0062(G*B<E,,>)(
M`XPDN````$2)QD$QU4Z-K"BAZ]EN2(GR2(GP2,'J&TC!X`5("=!,B?I)P>\"
M2,'B'HG`3`GZ3`'H38GE23'508G&13'H3HVL`:'KV6Y,B?%-B?!)P>@;2,'A
M!4P)P4F)\$C![@))P>`>B<E)"?!$B>9(`[0DP````$F)U$P!Z8G233'$08G/
M1#'@3(VD!J'KV6Y,B?A,B?Y(P>X;2,'@!4@)\$R)]DG![@)(P>8>B<!,"?9,
M`>!(`Y0DR````$V)Q$&)Q46)P$DQ]$P#A"30````1#'A3(VD"J'KV6Y,B>I,
MB>E(P>D;2,'B!4@)RDR)^4G![P)(P>$>B=),"?E,`>))B?1),<Q!B=:)]D0Q
MX$@#M"38````38VD`*'KV6Y-B?!,B?!)P>`%2,'H&TP)P(G`38T$!$R)Z$G!
M[0)(P>`>3`GH28G-18G$23'%B<E(`XPDX````$0QZDR-K!:AZ]EN3(GF3(GB
M2,'F!4C!ZAM("?*)TDF-=!4`3(GR2<'N`DC!XAY,"?))B<9!B?5),=:)P$4Q
M\$Z-M`&AZ]EN3(GI38GH2,'A!4G!Z!M(`X0DZ````$P)P4V)X$G![`))P>`>
MB<E-">!)B=1,`?%-,<1!B<Z)TD0QYD@#E"3P````3(VD,*'KV6Y,B?!,B?9(
MP>X;2,'@!4@)\$R)[DG![0)(P>8>B<!,">Y-B<5,`>!),?5!B<1%B<!$,>E,
M`X0D^````$R-K`JAZ]EN3(GB3(GA2,'I&TC!X@5("<I,B?%)P>X"2,'A'HG2
M3`GQ28GV3`'J23'.08G5B?9$,?!-C;0`H>O9;DV)Z$R)Z$G!X`5(P>@;3`G`
MB<!-C00&3(G@2,'@'D@#M"0``0``2<'L`DP)X$F)S$6)QDDQQ(G)2`.,)`@!
M``!$,>),C:06H>O9;DR)]DR)\DC!Y@5(P>H;2`GRB=))C3043(GJ2<'M`DC!
MXAY,">I)B<5!B?1),=6)P$@#A"00`0``13'H3HVL`:'KV6Y,B>%-B>!)P>@;
M2,'A!4P)P4V)\$G![@))P>`>B<E-"?!)B=9,`>E-,<9!B<V)TD0Q]DR-M#"A
MZ]EN3(GH3(GN2,'N&TC!X`5("?!,B>9)P>P"2,'F'HG`3`GF3`'P2`.4)!@!
M``!-B<1!B<9%B<!),?1,`X0D(`$``$0QX4R-I`JAZ]EN3(GR3(GQ2,'I&TC!
MX@5("<I,B>E)P>T"2,'A'HG23`GI28GU3`'B23'-08G4B?9$,>A(`[0D*`$`
M`$V-K`"AZ]EN38G@3(G@2<'@!4C!Z!M,"<")P$V-1`4`3(GP2<'N`DC!X!Y,
M"?!)B<Y%B<5),<:)R4@#C"0P`0``1#'R3(VT%J'KV6Y,B>Y,B>I(P>8%2,'J
M&T@)\HG228TT%DR)XDG![`)(P>(>3`GB28G$08GV23'4B<!%,>!-B?1.C80!
MH>O9;DR)\4G!Y`5(P>D;2`.$)#@!``!,">&)R4V-)`A-B>A)P>T"2<'@'DT)
MZ$F)U42)X4TQQ8G21#'N28G-2(VT,*'KV6Y(B<A)P>4%2,'H&TP)Z(G`3(TL
M!DR)]DG![@)(P>8>3(G`3`GV18GO2`GP22'$3(G`18G`2"'P00G$N-R\&X])
MB<9,`[0D0`$``$P!\DV)_DP!XDV)_$G!Y@5)P>P;30GT18GD20'42(G*2,'I
M`DC!XAY%B>9("=%(B?)("<I)(=5(B?*)]D@ARD$)U4B)PD@#E"1(`0``3`'"
M38GP3`'J38GU2<'H&TG!Y05-">A%B<!)`=!,B?I)P>\"2,'B'D6)Q4P)^DF)
MSTD)UTTA_$F)SXG)22'710G\28G'3`.\)%`!``!,`?Y-B>],`>9-B>Q)P><%
M2<'L&TT)_$6)Y$P!YDV)]$G![@))P>0>08GW30GT28G630GF32'P28G6B=)-
M(>9%"?!)B<9,`[0D6`$``$P!\4V)_DP!P4V)^$G!Y@5)P>@;30GP18G`3`'!
M38GH2<'M`DG!X!Y!B<Y-">A-B>5-"<5,(>Y-B>5%B>1-(<5$">Y)B<5,`ZPD
M8`$``$P!ZDV)]4@!\DR)]DG!Y05(P>X;20GU3(G^2<'O`DC!YAY%B>U,"?Y-
MB<=)`=5)"?=$B>I,(?E-B<=%B<!)(?=$"?E)B<=,`[PD:`$``$T!_$F)UTP!
MX4F)U$G!YP5)P>P;30GG18G_20'/3(GQ2,'A'DG![@)%B?Q,"?%)B?9)"<Y-
M(?5)B?:)]DDASD4)]4F)QDP#M"1P`0``30'P38GF30'H38GE2<'F!4G![1M-
M">Y%B?9-`<9)B=!(P>H"2<'@'D6)]4P)PDF)R$D)T$TAQTF)R(G)22'010G'
M28G`3`.$)'@!``!,`<9-B>A,`?Y-B>])P>@;2<'G!4T)^$6)P$D!\$R)YDG!
M[`)(P>8>18G'20GT2(G63`GF22'V2(G6B=),(>9!"?9(B<9(`[0D@`$``$@!
M\4R)_DP!\4V)_DC![AM)P>8%20GV3(GN2<'M`DC!YAY%B?9,">Y-B>5)`<Y)
M"?5$B?%-(>A-B>5%B>1)(?5%">A)B<5,`ZPDB`$``$P!ZDF)S4P!PDF)R$G!
MY05)P>@;30G%38GX2<'O`DG!X!Y%B>U-"?A)B?=)`=5-"<=$B>I-(?Y)B?>)
M]DTAQT4)_DF)QTP#O"20`0``30'\28G730'T28G62<'G!4G![AM-"?Y%B?9-
M`>9)B<Q(P>D"2<'D'D6)]TP)X4V)Q$D)S$TAY4V)Q$6)P$DAS$4)Y4F)Q$P#
MI"28`0``3`'F38G\3`'N38G]2<'L&TG!Y05-">Q%B>1)`?1(B=9(P>H"2,'F
M'D6)Y4@)\DB)SD@)UDDA]DB)SHG)2"'600GV2(G&2`.T)*`!``!,`<9-B>A,
M`?9-B>Y)P>@;2<'F!4T)\$6)P$D!\$R)_DG![P)(P>8>18G&3`G^28G720GW
M32'\28G7B=))(?=%"?Q)B<=,`[PDJ`$``$P!^4V)]TP!X4V)]$G!YP5)P>P;
M30G\18GD3`'A38GL2<'M`DG!Y!Y!B<]-">Q)B?5-">5-(>A)B?6)]DTAY44)
MZ$F)Q4P#K"2P`0``3`'J38G]3`'"38GX2<'E!4G!Z!M-"<5-B?!)P>X"2<'@
M'D6)[4T)\$V)YDD!U4T)QD2)ZDPA\4V)YD6)Y$TAQD0)\4F)QDP#M"2X`0``
M3`'V28G62`'Q2(G62<'F!4C![AM)"?9%B?9)`<Y,B?E)P>\"2,'A'D2)]DP)
M^4V)QTD)STTA_4V)QT6)P$DAST4)_4F)QTP#O"3``0``30'\28GW30'L28GU
M2<'G!4G![1M-"?U%B>U-`>5)B=1(P>H"2<'D'D6)[TP)XDF)S$D)U$TAYDF)
MS(G)22'410GF28G$3`.D),@!``!-`>!-B?Q-`?!-B?Y)P>P;2<'F!4T)YD6)
M]DT!QDF)\$C![@))P>`>18GT3`G&28G020GP32'%28G0B=))(?!%"<5)B<!,
M`X0DT`$``$@#A"38`0``3`'!38G@3`'I38GE2<'H&TG!Y05(`=!-"<5%B>U)
M`<U,B?E)P>\"2,'A'D6)Z$P)^4F)]TR)PDD)STTA_DF)]XGV22'/10G^3`'P
M38G&2<'F!4C!ZAM)"=9%B?9)`<9,B>!)P>P"2,'@'D2)\DD)Q+C6P6+*28G'
M3`.\).`!``!,`?Y)B<^)R4TQYT4Q_4F)UTP![DF)U4G!YP5)P>T;30G]38G'
M2<'H`DG!YQY%B>U-"?A)B<=,`[PDZ`$``$D!]42)[DP!^4V)YT6)Y$TQQT4Q
M_DF)]TP!\4F)]DG!YP5)P>X;30G^28G72,'J`DG!YQY%B?9)"==(B<)(`Y0D
M\`$``$D!SD2)\4P!XDV)Q$6)P$TQ_$4QY4F)S$P!ZDF)S4G![!M)P>4%30GL
M28GU2,'N`DG!Y1Y%B>1,">Y)B<5,`ZPD^`$``$D!U$2)XDT!Z$V)_46)_TDQ
M]44Q[DF)U4T!\$F)UDG![1M)P>8%30GU28G.2,'I`DG!YAY%B>U)"<Y(B<%(
M`XPD``(``$T!Q46)Z$P!^4F)]XGV33'W13'\38G'3`'A38G$2<'G!4G![!M-
M">=)B=1%B?])P>0>20'/2,'J`DD)U$B)PD@#E"0(`@``1(GY2`'R3(GV18GV
M3#'F03'U2(G.3`'J28G-2,'N&TG!Y05)"?5%B>U)`=5,B<))P>@"2,'B'D2)
M[DD)T$B)PD@#E"00`@``3`'R38GF18GD33'&13'W28GV3`'Z28GW2<'N&TG!
MYP5-"?=)B<Y(P>D"2<'F'D6)_TD)SDB)P4@#C"08`@``20'71(GZ3`'A38G$
M18G`33'T13'E28G43`'I28G52<'E!4G![!M-">5%B>U)`<U(B?%(P>X"2,'A
M'D6)[$@)SDB)P4@#C"0@`@``3`'!38GP18GV23'P13''38G@3`'Y38GG2<'H
M&TG!YP5-"<=)B=!(P>H"2<'@'D6)_TD)T$B)PD@#E"0H`@``20'/1(GY3`'R
M28GVB?9-,<9%,?5)B<Y,`>I)B<U)P>8%2<'M&TT)[D6)]DD!UDR)XDG![`)(
MP>(>18GU20G42(G"2`.4)#`"``!(`?),B<9%B<!,,>9!,?=,B>Y,`?I-B>](
MP>X;2<'G!4D)]TB)SDC!Z0)(P>8>18G_2`G.2(G!2`.,)#@"``!)`==$B?I,
M`<%-B>!%B>1),?!%,<9)B=!,`?%)B=9)P>@;2<'F!4T)QD6)]DD!SDR)Z4G!
M[0)(P>$>18GP20G-2(G!2`.,)$`"``!,`>%)B?2)]DTQ[$4QYTV)Q$P!^4V)
MQTG![!M)P><%30GG28G418G_2<'D'DD!STC!Z@))"=1(B<)(`Y0D2`(``$2)
M^4@!\DR)[D6)[4PQYD$Q]DB)SDP!\DF)SDC![AM)P>8%20GV18GV20'63(G"
M2<'H`DC!XAY$B?9)"=!(B<)(`Y0D4`(``$P!ZDV)Y46)Y$TQQ44Q[TF)]4P!
M^DF)]TG![1M)P><%30G]28G/2,'I`DG!YQY%B>U,"?E)B<=,`[PD6`(``$D!
MU42)ZDT!_$V)QT6)P$DQST4Q_DF)UTT!]$F)UDG!YP5)P>X;30G^28GW2,'N
M`DG!YQY%B?9,"?Y)B<=,`[PD8`(``$T!]$6)YDT!^$F)SXG)23'W13']38GW
M30'H38GU2<'G!4G![1M-"?U)B==(P>H"2<'G'D6)[4P)^DF)QTP#O"1H`@``
M30'H18G%3`'Y28GWB?9),==%,?Q-B>],`>%-B>Q)P><%2<'L&TT)_$V)]TG!
M[@))P><>18GD30G^28G'3`.\)'`"``!,`>%!B<Q,`?Y)B=>)TDTQ]T@#A"1X
M`@``1`'S13'X38GG2(E?($P!QDV)X$G!YP5)P>@;30GX2`'03(GR1`'&38GH
M2<'M`DG!X!Y-"<5-B>!)P>P"3#'J2<'@'D4!ZS'12(GR30G$2`'(2(GQ2,'J
M&TC!X04![D4!XD@)RDB)=PA,B5<0`=!,B5\800'!2(N$)(@"``!D2#,$)2@`
M``!,B0]U$DB!Q)@"``!;74%<05U!7D%?P^@2Y/__9BX/'X0``````$B%_P^$
MO@```$%7059!54%455-(@^P(3(L]*GD@`$V%_W1C#[8'A,!T=CP]='))B?Q)
M@\0!00^V!"2$P'0$/#UU[T$I_$F+'TB%VW0Y28GU28G^36/D3(G]#Q^`````
M`$R)XDR)]DB)W^@ZX___A<!U!T*`/",]="](@\4(2(M=`$B%VW7:2(/$"#'`
M6UU!7$%=05Y!7\-F#Q^$``````!%,>3KH`\?`$PI_4J-1",!2,']`T&);0!(
M@\0(6UU!7$%=05Y!7\,QP,-F#Q]$``!54TB)_4B#[!AD2(L$)2@```!(B40D
M"#'`2(U<)`1FD#'`2(G>2(GOZ`/___](A<!T,$AC5"0$2(L%.G@@`$B-!-!(
MBU`(2(722(D0=-)FD$B#P`A(BU`(2(722(D0=?#KODB+1"0(9$@S!"4H````
M=0=(@\086UW#Z+KB__]FD$%7059!54%455-(B?-(B?U(@^PH9$B+!"4H````
M2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z'GB__](C70D%$F)Q$B)[S'`Z&?^__](
MA<`/A`X!``!(B<=)B<7H4^+__TDYQ`^&X@```$QC="042<'F`P^V10"$P`^$
MJP$``#P]#X2C`0``2(GHZPT/'X0``````(#Z/70+2(/``0^V$(32=?!(*>A(
MF$P#-4QW(`!*C7P@`NBRXO__2(7`28D&#X1X`0``2&-4)!1(BP4J=R``2(U-
M`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]=!)(@\$!#[9!_TB#
MP@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`2(MT)!AD2#,T
M)2@````/A0X!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#_TF#Q0&$P$&(
M1?]U[.O"9I!,BSV1=B``28,_``^$O````$R)^#'2ZPL/'X0``````$2)ZDB#
MP`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%CX8@`(7`=#M,B?_H^^'__TB%P$B)
M!4%V(``/A'T```!-8\5(B<%.C33%`````$K'1,$(`````$2);"04Z9'^__]F
MD$B)]\<%0X8@``$```#H=N'__TB%P'1#36/%3(G^2(G'3HTTQ0````!,B40D
M"$R)\NBCX?__3(M$)`A(B<%(B074=2``ZZ4QP.EX_O__OA````!%,>WI8?__
M_[C_____Z=[^___H;^#__P\?@`````!!5D%505154TB![*````!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@S!"4H````#X4I
M`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HT]___TB%P$F)Q'3"28GE
M3(GGZ/C@__](A<!(B<,/A*0```"`>Q,N#X2R````2(/#$TB)[^C&W___2(G?
M28G&Z+O?__]!C7P&`DAC_^AFX/__2(T-:QP``$F)QDB)QTF)V4F)Z$C'PO__
M__^^`0```#'`Z`#A__^_`0```$R)ZDR)]NA(W___@_C_3(GW=!"+1"08)0#P
M```]`$```'1HZ/O>__],B??HX][__TR)Y^A;X/__2(7`2(G##X5C____#Q^`
M`````$R)Y^AXW___2(GOZ"#?___I\O[__P\?``^V0Q2$P`^$)/___SPN#X4Z
M____@'L5``^$$O___^DK____#Q]$``#HD_[__^N6Z/3>__]FD&8N#Q^$````
M``!32(G[BSWV<R``Z('?__](C9#X`0``2(G>OP$```#H!>#__X7`=`DQP%O#
M#Q]$``"+/<IS(`#H5=___XN`$`(``"4`\```/0!```!T'8L]K7,@`.@XW___
MBX`0`@``)0#P```]`*```'6]2(G?O@(```#HB=___X7`#Y3`#[;`6\,/'T0`
M`&8N#Q^$``````!!54%428G\55-(C3T*&P``28GUNO\/``!(@>P8$```2(GF
M9$B+!"4H````2(F$)`@0```QP.C.W?__A<!^<HU0_TB)XTACZH`\+`!T6TAC
MZ$B)ZKXO````2(G?Z%C>__](A<!T2XL]!7,@`.B0WO__2(GI2(G:3(GF2(G'
MZ/_>__](BX0D"!```&1(,P0E*````'4W2('$&!```%M=05Q!7<-F#Q]$``"%
MTG6D#Q]``(L]NG(@`.A%WO__3(GJ3(GF2(G'Z*_=___KMNB(W?__2(/L"(L]
MEG(@`.@AWO__2(L5DG`@`$B-#3,<``!(C34U&@``2(G'2(/$".D8WO__2(/L
M"(L]9G(@`.CQW?__2(G'Z+G___^+/5-R(`#HWMW__TR-!<`;``!(C16@%```
M2(TU#AH``$4QR4B)QTB#Q`A,B<'I]]W__P\?@`````!54TB!["@@``!D2(L$
M)2@```!(B80D&"```#'`Z*?<__],C0VM&0``2(T-VQD``$&)P+H!$```,<"^
M`0```$B)Y^@RWO__A<!X9DB-K"00$```N@`0``!(B>=(B>[H5MS__X7`2(G#
M>$>->`%(8__H1-W__TB%P'0W2&/;2(GN2(G'2(G:Z!;=___&!!@`2(N4)!@@
M``!D2#,4)2@```!U$TB!Q"@@``!;7<,/'T0``#'`Z]KH3]S__P\?@`````#I
M.____Y!F+@\?A```````05=!5D%5051)B?154TB)^TB-/3$9``!(@>PH$```
M9$B+!"4H````2(F$)!@0```QP$B-="0,Z/7W__^^+P```$B)WTB)Q>C]V___
M2(7`=#U(C3WZ&```2(G>,<#H'_G__TB)V$B+C"08$```9$@S#"4H````#X56
M`0``2('$*!```%M=05Q!74%>05_#2(G?3(TMKQ@``.B4V___2(TUNQ@``$&)
MQDR)YTR-9"0008/&`>BAW/__28G'9@\?1```387_=(M!@#\`30]$_4B%[703
M3(G^2(GOZ-/;__^%P`^$J0```$R)_^A#V___B<)(F$&`?`?_+W4:#Q^`````
M`(/J`4ACPD&`?`?_+T'&!`<`=.U$`?*!^O\/```/CR[___](@^P(2(T-4AD`
M`$R-#2P8``!338GXN@`0``"^`0```$R)YS'`Z%S<__^+/?YO(`#HB=O__TB-
MD/@!``!,B>:_`0```.B5VO__A<!:674=BSW9;R``Z&3;__^+@!`"```E`/``
M`#T`@```=!9(C37)%P``,?_HO-O__TF)Q^D<____O@$```!,B>?HG]O__X7`
M==E(C3V5%P``3(GFZ+SW__],B>?HO-K__^F3_O__Z&+:__]F+@\?A```````
M#[8/2(GXA,ET&$B-5P%FD(#Y+P^V"D@/1,)(@\(!A,EU[O/#9I!F+@\?A```
M````55-(@^P(2(7_=#4/MB](B?M`A.UT*N@%VO__2(U4`_](.=-R%.M/9@\?
MA```````2(/J`4@YTW1'@#HO=/+K+;\"````Z([:__](A<`/A)4```"Z+@``
M`&:)$$B#Q`A;7<-F#Q]$``"`.B]T.$B#Z@%(.=-R\D@YTW4J#Q]$``!`@/TO
M=+I(@\0(2(T]OQ8``%M=Z>#9__\/'X0``````(`Z+W4)2(/J`4@YTW+R2"G:
M2(U"`D@]`!```'<K2(T]W&X@`$B)WDB#P@&Y`!```.@KVO__2(/$"$B-!<!N
M(`!;7<,/'T0``$B#Q`@QP%M=PP\?1```9BX/'X0``````%-(C3U*%@``2(/L
M0&1(BP0E*````$B)1"0X,<!(BP6E%P``2(U<)`Q(B40D$$B+!9P7``!(B40D
M&$B+!9@7``!(B40D($B+!907``!(B40D*`^W!9`7``!FB40D,#'`Z(SU__](
MC3WP%0``,<#H?O7__TB-/>H5```QP.AP]?__2(T]Y14``#'`Z&+U__](C3W>
M%0``,<#H5/7__TB-/>`5```QP.A&]?__2(T]AQ4``#'`Z#CU__](C3W0%0``
M,<#H*O7__TB-/<P5```QP.@<]?__2(T]R!4``#'`Z`[U__](C3U8%0``,<#H
M`/7__TB-/;85```QP.CR]/__2(T]L14``#'`Z.3T__](C3VN%0``,<!(B=[H
M`_3__TB%P'012(T]<!4``$B)QC'`Z#WU__](C3V8%0``,<!(B=[HW//__TB%
MP'012(T]E!4``$B)QC'`Z!;U__](C3V.%0``,<!(B=[HM?/__TB%P'1`2(T]
MP10``$B)QC'`Z._T__](C363%0``2(T]Y!0``#'`Z-KT__](BT0D.&1(,P0E
M*````'5G2(/$0%O##Q]``$B-/4@5```QP$B)WNA?\___2(7`=!I(C3W"%```
M2(G&,<#HF?3__^NH#Q^``````$B-="0A2(T])!4``+D*````\Z9UC$B-="0K
M2(T]CA0``#'`Z&CT___I=/___^@6U___#Q]``&8N#Q^$``````!(@^P89$B+
M!"4H````2(E$)`@QP(L%]FL@`(/X_W092(M,)`AD2#,,)2@```!U14B#Q!C#
M#Q]``$B-="0$2(T]*Q0``#'`Z+7R__](A<!T(`^V$(#Z,`^5P(32#Y7"#[;2
M(=")!:=K(`#KM`\?1```,<#K[^B/UO__#Q^``````$B#[`CHA];__XG'Z%C6
M__](A<!T"TB+`$B#Q`C##Q\`,<#K]&:09BX/'X0``````$%7059)B?Y!54%4
M3(TM110``%533(TE,A0``$B#[&AD2(L$)2@```!(B40D6#'`2(T%(10``$C'
M1"10`````$B-;"0@3(U\)!Q(B40D($B-!?@3``!(B40D*$B-!?D3``!(B40D
M,$B-!>,3``!(B40D.$B-!=P3``!(B40D0$B-!>(3``!(B40D2.LA#Q]``$B)
MQ^@HU___2(7`=&-(@\4(387D=#=-B>5,BV4(3(G^,<!,B>_HEO'__TB%P$B)
MPTR)]G0%@#@`=<8QP$R)[TB#Q0CHR/+__TV%Y'7)2(M$)%AD2#,$)2@````/
MA7T```!(@\1H6UU!7$%=05Y!7\-,B??H2-7__TB)WTB)1"0(Z#O5__](BU0D
M"$B-?`("Z.35__](@^P(3(T-3Q(``$B-#6D3``!32,?"_____TB)QTV)\+X!
M````2(E$)!@QP.ASUO__3(M4)!A,B>\QP$R)UN@Y\O__6%KI+____^CEU/__
M#Q\`9BX/'X0``````$%7059!54%428G]55-(C3W4$0``2('LB($``&1(BP0E
M*````$B)A"1X@0``,<!(C07)$@``2(UL)"Q(QT0D0`````!(QX0DF```````
M``!(QT0D8`````!(B40D,$B-!8(1``!(B>Y(B40D.$B-!2$2``!(B40D<$B-
M!0X2``!(B40D>$B-!7@2``!(B80D@````$B-!1`2``!(B80DB````$B-!6(2
M``!(B80DD````$B-!3H2``!(B40D4$B-!4L2``!(B40D6#'`Z`#P__](A<!T
M"8`X``^%8@0``#'`Z&O]__](A<!(B<,/A&P$``!(B=_HU]/__TB-?``!Z(74
M__^`.P!)B<9)B<1T,&:01`^V`TB-#?T1``!,B><QP$C'PO____^^`0```$B#
MPP%)@\0"Z`_5__^`.P!UTDR-9"1P2(T]2A$``.L1#Q]``$F#Q`A)BSPD2(7_
M=#,QP$B)[NAI[___2(7`2(G#=.&`.`!TW$B)Q^AT]/__A<!TT$B)W^B@T___
M2(7`2(G#=5I(BUPD,$B%VP^$:@$``(`[`$&\`0```'4EZ5H!``!FD$ECQ$B+
M7,0P2(7;#X1'`0``08/$`8`[``^$.@$``$B)W^@:]/__A<!TUDB)W^A&T___
M2(7`2(G#=,9(B=_HWM+__TR)\8LQ2(/!!(V6__[^_O?6(?*!XH"`@(!TZ(G6
MP>X0]\*`@```#T362(UQ`D@/1,Z)UD``UDB#V0-,*?%$C;P(!`0``$UC_TR)
M_^A&T___28G$2(T%VA```$%63(T-JP\``$B-#<$0``!)B=A02,?"_____[X!
M````3(GG,<#HTM/__[[``0``3(GGZ/W1__^#^/]!6$%9#X2`````BSU:9R``
MZ.72__](C9#X`0``3(GFOP$```#H:=/__X7`#X29````28M-`$B+/6YG(`!(
MC14G$0``38G@O@$````QP.A8T___,<!(BXPD>($``&1(,PPE*`````^%3@D`
M`$B!Q(B!``!;74%<05U!7D%?PP\?1```,=OIV_[__Y#H4]'__T2+"$&#^1$/
MA&[___])BTT`2(L]`V<@`$B-%7P0``!-B>"^`0```#'`Z.W2__\QP.N39@\?
MA```````BSV:9B``Z"72__^+@!`"```E`/```#T`0```#X5&____BSUY9B``
MZ`32__^+F!0"``#H6='__SG##X4H____BSU;9B``Z.;1__^+@!`"```E_P$`
M`#W``0``#X4'____3(G_Z-#1__](C3T1#P``2(G#2(GN,<#H!.W__TB%P`^$
MZP$``$B)Q^A+T?__28M]`$B)QNBW]/__2(7`2(G%#X3+`0``2(GOZ-/0__^#
M^`-^-DACT$B-/1\/``"Y!0```$B-=!7\\Z9U'H/X!`^$Q`8``(/H!$B8@'P%
M_R\/A+0&```/'T0``#'`Z)'Y__^%P'45,?9(B>_H@]'__X7`B00D#X5Q`0``
M2(TU;`X``$B-/=D-```QP#'MZ+'M___H)-#__TB-#>X.``!,C0U^#0``2,?"
M_____TV)X+X!````2(G?44B-#:@.``!0,<#HI-'__UA:ZU,/'X0``````.BS
MS___@S@1=5/HV<___TB-#:,.``!(@^P(@\4!3(T-+`T``$V)X$C'PO____]1
M2(T-;`X``%50O@$```!(B=\QP.A1T?__2(/$(+[``0``2(G?Z'C/__^#^/]T
MHTR)Y^A+S___2(T]S`P``$B)WC'`Z/KL__](B=_H4OG__TB)V.FD_?__9BX/
M'X0``````$B)QTB)!"3H-/G__TB+!"1(B<?HT,___^E]_?__2(T]C@T``$&\
M`0```.L5#Q]``$ECQ$&#Q`%(BWS$4$B%_W0I,<!(B>[H1>O__TB%P'3@@#@`
M=-M(B<?HB\___TB%P$B)PW3+Z4?[__^_#0```$B-'4$-``#I0_O__P\?1```
M28MM`.DL_O__3(VT)'`!``"Z`@```$C'QN[___]!B<>)Q^A!T/__N@8```!,
MB?9$B?_H2<___X"\)'`!````=0Z`O"1Q`0``0P^$H04``(L\)#'2,?9,C:PD
MH````.@%T/__N(FKS>](QX0DH`````$C16=(QX0DN````'94,A!(B80DJ```
M`+C^W+J82,>$),@`````````2(F$)+````"X\.'2PTC'A"30`````````$B)
MA"3`````28U%.,>$)!@!````````2(E$)!!FD(L\)+H`@```3(GVZ*#.__^%
MP$B)Q4&)P`^.LP$``$B+E"3(````2&/%C33"2#GR#X>+`0``2(N4)-````!(
MP>@=2(FT),@```!(`=!(B80DT````$ACA"08`0``A<`/A$P!``!!N$````!(
MBW0D$$$IP$0YQ40/3L5(C3P&3(GV26/(2(G*28G/2(E,)`CH3<[__XN$)!@!
M``!$`?B#^$")A"08`0``#X53____08GH3(GO12GX3(M\)`A$B40D'.@KTO__
M1(M$)!Q-`?</'P!!@_@_#XZX`P``08U`P(E$)!S!Z`:)Q8E$)`A(@\4!2,'E
M!DP!_68N#Q^$``````!)BQ=,B>])@\=`2(F4)-@```!)BU?(2(F4).````!)
MBU?02(F4).@```!)BU?82(F4)/````!)BU?@2(F4)/@```!)BU?H2(F4)``!
M``!)BU?P2(F4)`@!``!)BU?X2(F4)!`!``#HA='__TPY_760BT0D"$2+1"0<
MP>`&02G`2(M\)!!)8]"Y2````$B)[D2)1"0(Z#?-__]$BT0D"$2)A"08`0``
MZ57^__\/'T0``$V)]^D8____#Q^$``````!(BXPDT````$B-40'I;/[__XL\
M).BGS/__2(NL),@```!,B[0DT````$B)Z$C!Z`.#X#^-4`%(F,:$!-@```"`
M@_HX#X^1`@``N#@````IT$ACTHG!28U$%3B#^0@/@[<"``#VP00/A60#``"%
MR70,]L$"Q@``#X5G`P``3(GP3(GO1(BT)!,!``!(P>@80(BL)!<!``!,C;PD
M0`$``(B$)!`!``!,B?!,C:PD(0$``$C!Z!"(A"01`0``3(GP38UW*$C!Z`B(
MA"02`0``2(GH2,'H&(B$)!0!``!(B>A(P>@0B(0D%0$``$B)Z$R)_4C!Z`B(
MA"06`0``Z#'0__](BX0DH````$B)PHB$)",!``!(P>H81`^VPHB4)"`!``!(
MB<)(P>H0B)0D(0$``$B)PDB+A"2H````2,'J"(B4)"(!``!(B<*(A"0G`0``
M2,'J&(B4)"0!``!(B<)(P>H0B)0D)0$``$B)PDB+A"2P````2,'J"(B4)"8!
M``!(B<*(A"0K`0``2,'J&(B4)"@!``!(B<)(P>H0B)0D*0$``$B)PDB+A"2X
M````2,'J"(B4)"H!``!(B<*(A"0O`0``2,'J&(B4)"P!``!(B<)(P>H0B)0D
M+0$``$B)PDB+A"3`````2,'J"(B4)"X!``!(B<*(A"0S`0``2,'J&(B4)#`!
M``!(B<)(P>H0B)0D,0$``$B)PDC!Z@B(E"0R`0``Z0P````/'P!%#[9%`$F#
MQ0%(C0V0"```2(GO,<!(Q\+_____O@$```!(@\4"Z*;+__],.?5UT4B-!;L(
M``#&A"1H`0```%!!5TB-#74(``!,C0TY!P``O@$```!-B>!(Q\+_____2(G?
M,<#H:,O__UE>Z2;Z__]-BVT(387M#X1$^?__3(GOZ-3)__](@_@##X8R^?__
M28UT!?Q(C3T>"```N04```#SIDD/1.WI%OG__TR)_>GE_/__N$````!(8\HI
MT$F-3`TXB<)T#S'`B<:#P`$YT,8$,0!R\TR)[^@LSO__28U5.+D'````,<!(
MB=?S2*OI8OW__XG*2,<``````$C'1!#X`````$B-4`A(@^+X2"G0`<B#X/B#
M^`@/@C?]__^#X/@QR8G.@\$(.<%(QP0R`````'+OZ1S]__^`O"1R`0``00^%
M4?K__X"\)',!``!##X5#^O__@+PD=`$``$@/A37Z__^`O"1U`0``10^%)_K_
M_T2+/"2Z`@```$C'QL;___]$B?_H*,K__[HI````3(GV1(G_Z##)__](C052
M!P``4$%6Z9K^__^0QP``````QT0(_`````#IF?S__S'_9HE\"/[IC?S__^B4
MR/__9I!F+@\?A```````059!54%455-(@^P0BSV.72``3(UL)`1D2(L$)2@`
M``!(B40D"#'`Z`3)__](C3V@!0``QH"Q`````4R)[C'`Z#SD__](A<!T"8`X
M,0^$;@(``#'`Z`?O__^+/4%=(`#HS,C__TB--:@&``"Y"P```+H!````2(G'
MZ(O(__](A<`/A+L```"#/8-M(``!2(M`$$R+8"@/CJ8````Q[;L!````ZR\/
M'T``28MV$$B+!55M(`!(8]-(BSS0Z$'(__^%P'5MBP5';2``@\,!@\4!.=A^
M8XL]QUP@`.A2R/__,<E(8]5,B>9(B<?HJLC__TB%P'0]3(LP08M&#"4`!"``
M/0`$``!THHL]E%P@`.@?R/__3(GVN0(````QTDB)Q^B-Q___2(G&ZX0/'X0`
M`````(L%VFP@`(U0_SGJ#X0_`0``BSU97"``Z.3'__](C37%!0``N0,```"Z
M`0```$B)Q^BCQ___2(7`2(G#=#5(BT`0BSTI7"``2(LHZ+''__](C164!0``
M2(G'2(GNZ!?'__](BT,02(L8]D,.0`^%*0(``(L]^%L@`.B#Q___2(TU:P0`
M`+D#````N@$```!(B<?H0L?__TB%P$B)Q70]2(T]S`,``#'`3(GNZ*'B__](
MA<!(B<,/A&T!``!(BT40BSVK6R``3(L@Z#/'__](B=I(B<=,B>;HG<;__XL]
MCUL@`.@:Q___2(T]>P,``,:`L0````!,B>XQP.A2XO__2(7`2(G#2(D%W6L@
M``^$CP```+[``0``2(G'Z.+%__^-4`&#^@%V"8/X$0^%F`$``$B+1"0(9$@S
M!"4H````#X5_`0``2(/$$%M=05Q!74%>PX/X`0^.N/[__[L!````9I"+/0I;
M(`"#PP'HDL;__TR)YDB)Q^B7Q?__.1UA:R``?]_IB_[__V8N#Q^$``````"`
M>`$`#X2/_?__Z8/]__^02(L],6L@`.C4\/__2(7`2(D%,FL@``^$^@```$B+
M11!,BR41:R``2(L8BT,,)0`$(``]``0```^%F0```$B+>Q!,B>;HG\;__T&)
MQ$B+11!(BQB+0PPE``0@`#T`!```=5)(BU,02(L%RVH@`$B-/=P$``!$B>%(
MBS`QP.COQ?__#Q^``````$B+!:EJ(`"+/3M:(`!,BR!(BT402(L8Z+S%__],
MB>9(B=_HL>;__^F'_O__BST66B``Z*'%__\QTKD"````2(G>2(G'Z`_%__](
MB<+KD(L]]%D@`.A_Q?__N0(```!(B<<QTDB)WNCMQ/__2(G'Z4;___^+/<]9
M(`#H6L7__TB)WDB)Q^AWQ?__Z;S]__](C3T+!```Z$[%___HD<3__XG!2(L%
M"&H@`$B-/4$$``!(B=I(BS`QP.@LQ?__9I!F+@\?A```````55-(B?U(@^P(
MZ#+J__\/MA!(B<.$TG0:2(U``0\?0`"`^B\/MA!(#T382(/``832=>XQP.@G
M[?__2(7M=!Z%P'0:@'T``'042(TU9P(``$B)W^AYQ?__2#G8=`=(@\0(6UW#
M2(/$"$B)[UM=Z8_C__]F+@\?A```````#Q]$``!(C07A6"``2(7`=`Q(BPCI
M',3__P\?0``QR>D1Q/__D$%7059!B?]!54%43(TE?E0@`%5(C2U^5"``4TF)
M]DF)U4PIY4B#[`A(P?T#Z.?"__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!
M_Q3<2(/#`4@YZW7J2(/$"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L
M"$B#Q`C#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!
M4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!0
M05)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!
M4E]#3$5!3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!
M5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X
M`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T
M96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M+0``
M``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````<&5R
M;'AS:2YC`````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N
M9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD``````````"5S.B!E>&5C=71I;VX@;V8@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^
M)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*
M+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!
M4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D
M14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I
M.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E
M14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG
M+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@
M)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F
M9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q
M6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`]
M(')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@
M;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970[
M"B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D
M:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X
M("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@
M,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP
M86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M"FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*
M8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%
M35!]+R1B87-E;F%M921E>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I
M;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE
M;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@
M?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I
M('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S
M=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K
M97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H
M.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T
M*3L*<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]
M"F]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET
M=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@
M)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S
M=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*
M)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F
M*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1E>'0L("1C<F,I(#T@0%\["FUY("@D9F@L("1F:6QE;F%M
M92D["B1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PII9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N
M86UE.PIP=7-H($!T;7!F:6QE+"`D9FEL96YA;64["GT*96QS92!["G)E='5R
M;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["GT*;W!E
M;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PIR971U<FXH)&9H+"`D9FEL96YA;64I.PI]"G-U8B!?<V5T7W!R;V=N86UE
M('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P
M<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H
M)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@
M)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R
M;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[
M4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U
M8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O
M;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T
M92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]
M"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%
M04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE
M;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU
M92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*```````!&P,[
MY````!L```#P@?__,`$``/"#__^`!@``\(7__P`!```@A___6`$``'">__^H
M`0``0)___Q@"``#`G___2`(``!"B__^8`@``D*/__^`"```@I/__``,``/"D
M__]``P``(*7__U@#``!PI?__<`,``#"F__^@`P``0*;__[@#```@J/__&`0`
M`%"H__\P!```4*G__X`$``!PJ___J`0``/"K___(!```(*S__^@$``"@K?__
M2`4``/"Y__\`!@``$+[__T@&``"0OO__L`8``+"^___(!@``(+___Q`'````
M````%``````````!>E(``7@0`1L,!PB0`0<0%````!P```#HA/__*@``````
M````````%``````````!>E(``7@0`1L,!PB0`0``)````!P```"X@/__$```
M```.$$8.&$H/"W<(@``_&CLJ,R0B`````$P```!$````P(7__T87````0@X0
MCP)"#AB.`T8.((T$0@XHC`5%#C"&!D$..(,'1P[0!0,=%PH..$$.,$$.*$(.
M($(.&$(.$$(."$$+````;````)0```#`G/__R@````!+#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&00XX@P=$#D`"<PH..$/##C!!Q@XH0LP.($+-#AA"S@X0
M0L\."$H+7`XX0<,.,$'&#BA"S`X@0LT.&$+.#A!"SPX(`````"P````$`0``
M()W__WX`````00X0A@)!#AB#`T<.,`)M"@X800X000X(00L``````$P````T
M`0``<)W__TD"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'2@Y@
M`R8!"@XX00XP00XH0@X@0@X80@X00@X(1`L`````1````(0!``!PG___=`$`
M``!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!#B!"#AA"
M#A!"#@A+"P``````'````,P!``"HH/__@0````!!#A"#`FD*#@A&"P)0#@@\
M````[`$``!BA___0`````$(.$(T"0@X8C`-$#B"&!$$.*(,%5@[`(`)\"@XH
M00X@00X80@X00@X(1PL`````%````"P"``"HH?__,`````!$#A!G#@@`%```
M`$0"``#`H?__20````!$#A!]#@@`+````%P"``#XH?__N0````!!#A"&`D$.
M&(,#1P[`0`*?"@X800X000X(1@L`````%````(P"``"(HO__!0``````````
M````7````*0"``"`HO__U@$```!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&
M00XX@P=1#N`@`F0*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P*9#N@@3P[P('D.
MZ"!!#N`@````%`````0#````I/__)```````````````3````!P#```8I/__
M\0````!!#A"&`D$.&(,#1`X@`ED*#AA!#A!!#@A'"V(*#AA(#A!!#@A-"WD*
M#AA(#A!!#@A&"T0.&$,.$$$."``````D````;`,``,BD__\2`@```$$.$(,"
M2PY0`YX!"@X000X(10L`````'````)0#``#`IO__>0````!$#B!O"@X(10L`
M```````<````M`,``""G__\D`````$0.$%@*#@A$"P```````%P```#4`P``
M,*?__W,!````0@X0CP)"#AB.`T4.((T$0@XHC`5(#C"&!D$..(,'2PZ@`0+6
M"@XX00XP00XH0@X@0@X80@X00@X(00MH#J@!3PZP`7$.J`%!#J`!`````+0`
M```T!```4*C__T0,````0@X0CP)"#AB.`T(.((T$0@XHC`5$#C"&!D$..(,'
M3@[`@P(#,P(.R(,"4@[0@P)H#LB#`D(.P(,"`FX*#CA!#C!!#BA"#B!"#AA"
M#A!"#@A&"P.-`0[(@P)(#M"#`D@.R(,"00[`@P)D#LB#`E4.T(,"2`[8@P)!
M#N"#`E,.P(,"`[P%#LB#`D(.T(,":`[(@P)!#L"#`@,V`0H.R(,"0@[0@P)&
M"P!$````[`0``.BS__\4!````$(.$(X"0@X8C0-"#B",!$$.*(8%00XP@P9$
M#D`#:P(*#C!!#BA!#B!"#AA"#A!"#@A!"P`````T````-`4``,"W__]Q````
M`$$.$(8"00X8@P-'#B`"5PH.&$$.$$$."$$+1`X81`X000X(`````"P```!L
M!0``:'W___<!````00X0A@)!#AB#`T0.4`.<`0H.&$$.$$$."$$+`````!0`
M``"<!0``V+?__Q\``````````````$0```"T!0``X+?__V4`````0@X0CP)"
M#AB.`T4.((T$0@XHC`5(#C"&!D@..(,'30Y`<@XX00XP00XH0@X@0@X80@X0
M0@X(`!0```#\!0``"+C__P(`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(`?````````0!\```````````````````$`
M`````````0`````````!`````````,0!`````````0`````````3`@``````
M``P`````````6!H````````-`````````+17````````&0````````#0JR``
M`````!L`````````"``````````:`````````-BK(```````'``````````(
M`````````/7^_V\`````F`(````````%`````````"`-````````!@``````
M``"0`P````````H`````````RP0````````+`````````!@`````````%0``
M``````````````````,`````````R*T@```````'`````````#@3````````
M"``````````@!P````````D`````````&``````````8````````````````
M````^___;P`````!```(`````/[__V\`````N!(```````#___]O``````(`
M````````\/__;P````#L$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````.BK(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P`````06P```````$=#
M0SH@*%5B=6YT=2`U+C,N,2TQ-G5B=6YT=3,I(#4N,RXQ(#(P,38P-#(Y`$=#
M0SH@*%5B=6YT=2`U+C,N,2TQ-'5B=6YT=3(I(#4N,RXQ(#(P,38P-#$S```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL
M9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+FEN:70`+G!L=``N<&QT+F=O=``N
M=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F1A=&$`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`#@"````````.`(````````<`````````````````````0``````````````
M`````!,````'`````@````````!4`@```````%0"````````(```````````
M``````````0````````````````````A````!P````(`````````=`(`````
M``!T`@```````"0````````````````````$````````````````````-```
M`/;__V\"`````````)@"````````F`(```````#T``````````4`````````
M"````````````````````#X````+`````@````````"0`P```````)`#````
M````D`D````````&`````@````@`````````&`````````!&`````P````(`
M````````(`T````````@#0```````,L$```````````````````!````````
M````````````3@```/___V\"`````````.P1````````[!$```````#,````
M``````4``````````@`````````"`````````%L```#^__]O`@````````"X
M$@```````+@2````````@``````````&`````@````@`````````````````
M``!J````!`````(`````````.!,````````X$P```````"`'````````!0``
M```````(`````````!@`````````=`````$````&`````````%@:````````
M6!H````````:````````````````````!````````````````````'H````!
M````!@````````"`&@```````(`:````````$````````````````````!``
M````````$`````````!_`````0````8`````````D!H```````"0&@``````
M`/`!```````````````````(````````````````````B`````$````&````
M`````(`<````````@!P````````R.P``````````````````$```````````
M`````````(X````!````!@````````"T5P```````+17````````"0``````
M``````````````0```````````````````"4`````0````(`````````P%<`
M``````#`5P```````-!````````````````````(````````````````````
MG`````$````"`````````)"8````````D)@```````#D````````````````
M````!````````````````````*H````!`````@````````!XF0```````'B9
M````````1`8```````````````````@```````````````````"T````#@``
M``,`````````T*L@``````#0JP````````@````````````````````(````
M````````````````P`````\````#`````````-BK(```````V*L````````(
M````````````````````"````````````````````,P````!`````P``````
M``#@JR```````."K````````"`````````````````````@`````````````
M``````#1````!@````,`````````Z*L@``````#HJP```````.`!````````
M!@`````````(`````````!``````````@P````$````#`````````,BM(```
M````R*T````````X`@``````````````````"``````````(`````````-H`
M```!`````P``````````L"````````"P````````(```````````````````
M``@```````````````````#@````"`````,`````````(+`@```````@L```
M`````(@0```````````````````@````````````````````Y0````$````P
M````````````````````(+````````!:`````````````````````0``````
M```!``````````$````#`````````````````````````'JP````````[@``
=``````````````````$`````````````````````
